===============================
group-based-policy-ui
===============================

Horizon modules for Group Based Policy

* Free software: Apache license
* Documentation: http://gbp.readthedocs.org/en/latest/
* Source: http://git.openstack.org/cgit/openstack/group-based-policy-ui
* Bugs: http://bugs.launchpad.net/group-based-policy-ui

Features
--------

* TODO
